breed [ villages village ]
breed [ farms farm ]
breed [ industrial-plants industrial-plant ]
breed [ persons person ]
breed [ sources source ]
breed [ sensors sensor ]

globals
[
  setup-randomseed
  rivers-and-lake
  land
  time
  month
  nutrient-initial
  biomass-initial
  detritus-initial
  oxygen-hyp-initial
  nutrient-overall-max
  nutrient-overall-min
  biomass-overall-max
  biomass-overall-min
  oxygen-overall-max
  oxygen-overall-min
  detritus-overall-max
  detritus-overall-min
  min-nutrient
  max-nutrient
  sum-nutrient
  min-biomass
  max-biomass
  sum-biomass
  min-detritus
  max-detritus
  sum-detritus
  min-oxygen
  max-oxygen
  sum-oxygen
  ehr        ;; epilimnion / hypolimnion volume ratio, dimensionless
  oxygen-epi ;; oxygen in epilimnion, MG / L
  k1         ;; growth-rate constant, L / MG YR, 0.2
  k2         ;; death-rate constant, 1 / YR,
  k3         ;; decay-rate constant, MG / L YR
  k4         ;; respiration-rate constnt, L / MG YR,
  k5         ;; solution-rate constant, 1 / YR
  onr        ;; oxygen-nutrient ratio, dimensionless
  feeding-rate-initial ;; 0.001 MG / L YR
  food-multiplier
  farmf
  drdgf
  Othres
  k2b
  k2a
  kaer
  TAXamount
  ndir1
  ndir2
]

patches-own
[
  is-lake?
  is-river?
  is-agro?
  is-industry?
  is-residential?
  is-groundwater?
  is-wood?
  category
  this-village
  nutrient        ;; MG / L
  biomass         ;; MG / L
  oxygen          ;; oxygen in hypolimnion, MG / L
  detritus        ;; MG / L
  growth-rate     ;; MG / L YR
  death-rate      ;; MG / L YR
  decay-rate      ;; MG / L YR
  oxygen-hyp        ;; oxygen in hypolimnion, MG / L
  total-oxygen      ;; average oxygen in lake, MG / L
  respiration-rate  ;; MG / L YR
  consumption-rate  ;; MG / L YR
  solution-rate     ;; oxygen to hypolimnion, MG / L YR
  aeration-rate     ;; mg / L YR
  feeding-rate      ;; MG / L YR
  algae-harvested
  detritus-dredged
]

villages-own
[
  mayor
  my-inhabitants
  my-farms
  my-industrial-plants
  my-patches
  nearest-water
  farm-algae            ;; farming rate, MG / L YR
  dredge                ;; dredging rate, MG / L YR
  ka                    ;; aeration-rate constant, ! / YR
  TAX
]

farms-own
[
  my-village
  my-employees
  ndir
  TAXthres
]

industrial-plants-own
[
  my-village
  my-employees
]

persons-own
[
  my-farm
  my-industrial-plant
  my-village
  is-farmer?
  is-worker?
]


to setup
  ca
  set time 0.0
  file-close-all
  ifelse behaviorspace-run-number > 0
  [
    set setup-randomseed new-seed
    random-seed setup-randomseed
    set farming-applied random-float 1.0
    set dredging-applied random-float 1.0
    set aeration-applied random-float 1.0
    set TAXapplied random-float 50
    set manure-spread random-float 15
    set awareness 1.0 + random-float 0.3
  ]
  [
    ifelse constant-seed? [ set setup-randomseed 2078503744 ] [ set setup-randomseed new-seed ]
    random-seed setup-randomseed
  ]

  setup-villages
  show ( word count villages " villages created" )
  setup-patches
  show ( word count patches " patches created" )
  setup-farms
  show ( word count farms " farms created" )
  setup-industrial-plants
  show ( word count industrial-plants " industrial plants created" )
  setup-persons
  show ( word count persons " persons created" )
  recolor-patches
  ask villages
  [
    ifelse any? my-inhabitants [ set mayor one-of my-inhabitants ask mayor [ set shape "person graduate" ] ] [ show "no mayor, no inhabitants" ]
    set nearest-water min-one-of patches with [ is-lake? ] [ distance myself ]
    ask nearest-water [ sprout-sensors 1 [ set color green set shape "x" ] ]
  ]
  ask max-one-of ( patches with [ is-agro? ] ) [ pycor ] [ set nutrient 0 sprout-sources 1 [ ] ]
  ask max-one-of ( patches with [ is-river? ] ) [ pycor ] [ set nutrient 0 sprout-sources 1 [ set shape "x" set size 1 set color blue] ]
  show ( word count villages " villages, " count farms " farms, " count industrial-plants " industrial plants " )
  ask farms with [ not any? my-employees ] [ die ]
  ask industrial-plants with [ not any? my-employees ] [ die ]
  show ( word count villages " villages, " count farms " farms, " count industrial-plants " industrial plants, " count persons with [ is-farmer? ] " farmers/farm workers and "
    count persons with [ is-worker? ] " industrial workers, " count persons with [ not is-farmer? and not is-worker? ] " unemployed ")
  initialise-constants

  set nutrient-overall-max 0
  set nutrient-overall-min 1e5
  set biomass-overall-max 0
  set biomass-overall-min 1e5
  set oxygen-overall-max 0
  set oxygen-overall-min 1e5
  set detritus-overall-max 0
  set detritus-overall-min 1e5
  reset-ticks
  if logging?
  [
    if file-exists? "LakeAnderson.csv" [ file-delete "LakeAnderson.csv" ]
    file-open "LakeAnderson.csv"
    file-print "T;N;B;D;OH;GR;DR;DEC;O;OE;RR;CR;SR;FR;AER;AH;DD"
  ]
end

to initialise-constants
  set ehr 0.1            ;; 0.1
  set oxygen-epi 10.0    ;; 10 MG / L
  set k1 0.2             ;; 0.2 L / MG YR
  set k4 0.445           ;; 0.445 L / MG YR
  set k3 0.0445          ;; k3 * detritus initial is assumed as 0.08 / YR, detritus initial being 2.0
  set k5 4.27            ;; 4.27 / YR
  set onr 2.67           ;; 2.67
  set farmf 0.0
  set drdgf 0.0
  set kaer 0.0
  set k2b 4.0            ;; 4 / YR, after policy implementation
  set k2a 4.0            ;; 4 / YR, before policy implementation
  set k2 4.0
  set nutrient-initial 40
  set biomass-initial 0.2
  set detritus-initial 2.0
  set oxygen-hyp-initial 9
  ( ifelse
    anderson-run = "algicide" [ set k2b 20 ]
    anderson-run = "aeration" [ set kaer 10 ]
    anderson-run = "dregding" [ set drdgf 1 ]
    anderson-run = "farming"  [ set farmf 2 ]
  )
  set TAXamount 11.0
  set ndir1 0.02
  set ndir2 -0.02
  ask villages
  [
    set ka kaer
  ]
  ask rivers-and-lake
  [
    set nutrient nutrient-initial
    set biomass biomass-initial
    set detritus detritus-initial
    set oxygen-hyp oxygen-hyp-initial
    set growth-rate 0.0
    set death-rate 0.0
    set decay-rate 0.0
    set respiration-rate 0.0
;;    set consumption-rate 4.27734
;;    set solution-rate 4.27
    set feeding-rate-initial 0.001
    set aeration-rate 0.0
  ]
  ask farms
  [
    set ndir ifelse-value ( TAXthres > [ TAX ] of my-village ) [ ndir1] [ ndir2 ]
    set TAXthres 1 + random 30
  ]
end


to setup-patches
  ask patches [ set this-village min-one-of villages [ distance myself ] set pcolor [ color ] of this-village + 3 ]
  ask patches
  [
    let this-patch self
    ask this-village
    [
      if my-patches = nobody [ set my-patches this-patch ]
      set my-patches ( patch-set this-patch my-patches )
    ]
    set is-river? false
    set is-lake? false
    set is-agro? false
    set is-industry? false
    set is-residential? false
    set is-wood? false
    set is-groundwater? false
    let that-village this-village
    if any? neighbors with [ this-village != that-village ] [ set is-river? true ]
  ]
  ask patches with [ pxcor * pxcor + pycor * pycor < 400 ] [ set is-lake? true set is-river? false ]
  set rivers-and-lake patch-set patches with [ is-lake? or is-river? ]
  set land patch-set patches with [ is-groundwater? ]
end

to recolor-patches
  ask patches
  [
    let distance-to-farm distance min-one-of farms [ distance myself ]
    let distance-to-industrial-plant distance min-one-of industrial-plants [ distance myself ]
    let distance-to-person distance min-one-of persons [ distance myself ]
    ( ifelse
      distance-to-farm > 5 and distance-to-industrial-plant > 5 and distance-to-person > 5
      [
        set pcolor green - 3
        set is-wood? true
        set is-groundwater? false
        set category "land"
      ]
      distance-to-person < distance-to-farm and distance-to-person < distance-to-industrial-plant and distance-to-person < 1
      [
        set pcolor yellow
        set is-residential? true
        set is-groundwater? true
        set category "land"
      ]
      distance-to-farm < distance-to-industrial-plant
      [
        set pcolor green
        set is-agro? true
        set is-groundwater? true
        set category "land"
      ]
      distance-to-farm > distance-to-industrial-plant
      [
        set pcolor red
        set is-industry? true
        set is-groundwater? true
        set category "land"
      ]
      [ set pcolor white ]
     )
     if is-river? or is-lake?
    [
      set pcolor blue
      set is-residential? false
      set is-industry? false
      set is-agro? false
      set is-wood? false
      set is-groundwater? false
      set category "water"
    ]
  ]
end

to setup-villages
  create-villages 6
  [
    while [ ( pxcor * pxcor + pycor * pycor < 730 ) or ( pxcor * pxcor + pycor * pycor > 1600 )]
    [
      set xcor random-xcor
      set ycor random-ycor
    ]
    set shape "building institution"
    set color 15 + 10 * who
    if color > 45 [ set color color + 70 ]
    set size 3
    set my-farms turtle-set nobody
    set my-industrial-plants turtle-set nobody
    set my-inhabitants turtle-set nobody
    set my-patches patch-set nobody
  ]
end

to setup-farms
  create-farms 100
  [
    set shape "house ranch"
    set size 2
    while [ ( ( pxcor * pxcor + pycor * pycor < 730 ) or ( pxcor * pxcor + pycor * pycor > 1600 ) )
            or [ is-lake? or is-river? ] of patch-here ]
    [
      set xcor random-xcor
      set ycor random-ycor
    ]
    set my-village min-one-of villages [ distance self ]
    set color [ color ] of my-village
    ask my-village [ set my-farms ( turtle-set my-farms myself ) ]
    set my-employees turtle-set nobody
  ]
end

to setup-industrial-plants
  create-industrial-plants 50
  [
    set shape "factory"
    set size 2
    while [ ( (  pxcor * pxcor + pycor * pycor < 730 ) or ( pxcor * pxcor + pycor * pycor > 2400 ) )
            or [ is-lake? or is-river? ] of patch-here ]
    [
      set xcor random-xcor
      set ycor random-ycor
    ]
    set my-village min-one-of villages [ distance self ]
    set color [ color ] of my-village
    ask my-village [ set my-industrial-plants ( turtle-set my-industrial-plants myself ) ]
    set my-employees turtle-set nobody
  ]
end

to setup-persons
  create-persons 1000
  [
    set shape "person"
    set size 1
    set my-farm turtle-set nobody
    set my-industrial-plant turtle-set nobody
    set my-village turtle-set nobody
    while [ ( ( pxcor * pxcor + pycor * pycor < 450 ) or ( pxcor * pxcor + pycor * pycor > 2400 ) )
            or [ is-lake? or is-river? ] of patch-here ]
    [
      set xcor random-xcor
      set ycor random-ycor
    ]
  ]
  show ( word count persons " created" )
  ask persons
  [
    set my-village min-one-of villages [ distance myself ]
    set my-farm min-one-of farms [ distance myself ]
    set my-industrial-plant min-one-of industrial-plants [ distance myself ]
    set color [ color ] of my-village
  ]
  ask persons
  [
    set is-farmer? false
    set is-worker? false
    let r random-float 1
    ( ifelse r < 0.1 [ set is-farmer? true ] r >= 0.1 and r < 0.5 [ set is-worker? true ] [ set is-farmer? false set is-worker? false ] )
    if is-farmer?
    [
      set shape "person farmer"
      ask my-farm [ set my-employees ( turtle-set my-employees myself ) ]
    ]
    if is-worker?
    [
      set shape "person service"
      ask my-industrial-plant [ set my-employees ( turtle-set my-employees myself ) ]
    ]
    ask my-village [ set my-inhabitants ( turtle-set my-inhabitants myself ) ]
  ]
end

to go
  show-feature
;; set time-variant and run-variant parameters
  ( ifelse
    anderson-run = "growth" or anderson-run = "micro version" [ set food-multiplier  1 ]
    anderson-run = "basic"  [ set food-multiplier 0.996909473817727 * exp ( time * 0.018176543850809 ) ]
    anderson-run = "recovery" [ set food-multiplier ifelse-value time <= 30 [ 10 ] [ 1 ] ]
  )
  if anderson-run != "micro version"
  [
    set k2 ifelse-value ( time < policy-impl-time ) [ k2a ] [ k2b ]
    ask villages
    [
      set farm-algae ifelse-value ( time < policy-impl-time ) [ 0.0 ] [ farmf ]
      set dredge ifelse-value ( time < policy-impl-time ) [ 0.0 ] [ drdgf ]
    ]
  ]
;; log levels and rates
  if logging?
  [
    file-print ( word  time "; "  max-nutrient  "; "  max-biomass  "; "  max-detritus "; "  max-oxygen
    "; "  mean [ growth-rate ] of rivers-and-lake  "; "  mean [ death-rate ] of rivers-and-lake
    "; " mean [ decay-rate ] of rivers-and-lake "; " mean [ total-oxygen ] of rivers-and-lake "; " oxygen-epi
    "; " mean [ respiration-rate ] of rivers-and-lake "; " mean [ consumption-rate ] of rivers-and-lake
    "; " mean [ solution-rate ] of rivers-and-lake "; " mean [ feeding-rate ] of rivers-and-lake
    "; " mean [ aeration-rate ] of rivers-and-lake "; " mean [ algae-harvested ] of rivers-and-lake
    "; " mean [ detritus-dredged ] of rivers-and-lake "; A" )
  ]
;; dissipate nutrient and biomass to neighbouring patches
  if dissipate? [ dissipate-nutrient ]
;; metabolise locally
  ask rivers-and-lake [ metabolise-in-water ]
;; actions taken by the farms and villages near the lake
  ask one-of villages [ decide-measures ]
  set month round ( time * 12 ) mod 12 + 1
  if month = 3 or month = 9 [ ask one-of farms [ decide-spreading-manure ] ]
;; final commands for this tick
  show-feature
  if max-nutrient < 1e-5 or mean [ nutrient ] of rivers-and-lake > 100 or min [ death-rate ] of rivers-and-lake < 0 or min [ growth-rate ] of rivers-and-lake < 0 [ stop ]
  if min-nutrient < nutrient-overall-min [ set nutrient-overall-min min-nutrient ]
  if max-nutrient > nutrient-overall-max [ set nutrient-overall-max max-nutrient ]
  if min-biomass < biomass-overall-min [ set biomass-overall-min min-biomass ]
  if max-biomass > biomass-overall-max [ set biomass-overall-max max-biomass ]
  if min-oxygen < oxygen-overall-min [ set oxygen-overall-min min-oxygen ]
  if max-oxygen > oxygen-overall-max [ set oxygen-overall-max max-oxygen ]
  if min-detritus < detritus-overall-min [ set detritus-overall-min min-detritus ]
  if max-detritus > detritus-overall-max [ set detritus-overall-max max-detritus ]
  set time time + DT
  if time > 200 [ file-close-all stop ]
  tick
end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; behaviour of the lake
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to dissipate-nutrient
  ask patches with [ is-lake? and ( nutrient > 0 or biomass > 0 ) ]
  [
    let wet-neighbors ( patch-set neighbors with [ is-lake? or is-river? ] self )
;;    show [ precision nutrient 3 ] of wet-neighbors
    let local-sum-nutrient sum [ nutrient ] of wet-neighbors
    let local-sum-biomass sum [ biomass ] of wet-neighbors
    let local-sum-detritus sum [ detritus ] of wet-neighbors
    let local-sum-oxygen-hyp sum [ oxygen-hyp ] of wet-neighbors
    ifelse equal-dissipation?
    [
      let divisor count wet-neighbors
      let mean-nutrient local-sum-nutrient / divisor
      let mean-biomass local-sum-biomass / divisor
      let mean-detritus local-sum-detritus / divisor
      let mean-oxygen-hyp local-sum-oxygen-hyp / divisor
      ask wet-neighbors
      [
        set nutrient mean-nutrient
        set biomass mean-biomass
        set detritus mean-detritus
        set oxygen-hyp mean-oxygen-hyp
      ]
    ]
    [
      let divisor ( count wet-neighbors - 1 )
      set nutrient local-sum-nutrient / ( divisor + 1 )
      set biomass local-sum-biomass / ( divisor + 1 )
      set detritus local-sum-detritus / ( divisor + 1 )
      set oxygen-hyp local-sum-oxygen-hyp / ( divisor + 1 )
      let mean-nutrient ( local-sum-nutrient - nutrient ) / divisor
      let mean-biomass ( local-sum-biomass - biomass) / divisor
      let mean-detritus ( local-sum-detritus - detritus ) / divisor
      let mean-oxygen-hyp ( local-sum-oxygen-hyp - oxygen-hyp ) / divisor
      ask other wet-neighbors
      [
        set nutrient mean-nutrient
        set biomass mean-biomass
        set detritus mean-detritus
        set oxygen-hyp mean-oxygen-hyp
      ]
    ]
    let new-local-sum-nutrient sum [ nutrient ] of wet-neighbors
    let new-local-sum-biomass sum [ biomass ] of wet-neighbors
    let new-local-sum-detritus sum [ detritus ] of wet-neighbors
    let new-local-sum-oxygen-hyp sum [ oxygen-hyp ] of wet-neighbors
    if abs ( new-local-sum-nutrient - local-sum-nutrient ) > 1e-5 [ show ( word "ERROR " new-local-sum-nutrient " != " local-sum-nutrient ) ]
    if abs ( new-local-sum-biomass - local-sum-biomass ) > 1e-5 [ show ( word "ERROR " new-local-sum-biomass " != " local-sum-biomass ) ]
    if abs ( new-local-sum-detritus - local-sum-detritus ) > 1e-5 [ show ( word "ERROR " new-local-sum-detritus " != " local-sum-detritus ) ]
    if abs ( new-local-sum-oxygen-hyp - local-sum-oxygen-hyp ) > 1e-5 [ show ( word "ERROR " new-local-sum-oxygen-hyp " != " local-sum-oxygen-hyp ) ]
;;    show [ precision nutrient 3 ] of wet-neighbors
  ]
  ask patches with [ is-river? and ( nutrient > 0 or biomass > 0 ) ]
  [
    let wet-neighbors ( patch-set neighbors with
      [ ( is-river? or is-lake? ) and pycor <= [ pycor ] of myself ] self )
    let mean-nutrient mean [ nutrient ] of wet-neighbors
    let mean-biomass mean [ biomass ] of wet-neighbors
    let mean-detritus mean [ detritus ] of wet-neighbors
    let mean-oxygen-hyp mean [ oxygen-hyp ] of wet-neighbors
    ask wet-neighbors
    [
      set nutrient mean-nutrient
      set biomass mean-biomass
      set detritus mean-detritus
      set oxygen-hyp mean-oxygen-hyp
    ]
  ]

  ask patches with [ is-groundwater? and nutrient > 0 ]
  [
    if any? sources-here [ ask sources-here [ die ] ]
    let my-nearest-water min-one-of rivers-and-lake [ distance myself ]
    let x [ pxcor ] of my-nearest-water
    let y [ pycor ] of my-nearest-water
    let dry-neighbors patch-set nobody
    sprout-sources 1 [ set shape "x" set size 1 set color green facexy x y set dry-neighbors patches with
      [ is-river? or is-lake? or is-groundwater? ] in-cone 3 45 ]
    let local-sum-nutrient sum [ nutrient ] of dry-neighbors with [ is-groundwater? ]
    set dry-neighbors other dry-neighbors
    if any? dry-neighbors
    [
;;        show ( word "before " [ ( list pxcor pycor category precision nutrient 3 ) ] of ( patch-set self dry-neighbors ) )
      ifelse not any? dry-neighbors with [ is-river? or is-lake? ]
      [
        let mean-nutrient local-sum-nutrient / count dry-neighbors
        ask dry-neighbors
        [
          set nutrient mean-nutrient
        ]
        set nutrient 0
      ]
      [
        ask dry-neighbors
        [
          set nutrient nutrient + local-sum-nutrient / count dry-neighbors
;;          show ( word nutrient " is-lake? " is-lake? " is.river? " is-river? )
        ]
        set nutrient 0
      ]
;;        show ( word "after  " [ ( list pxcor pycor category precision nutrient 3 ) ] of ( patch-set self dry-neighbors ) )
    ]
  ]
  ask sources with [ nutrient < 1e-5 ] [ die ]
end

to metabolise-in-water
;; rate equations
  let local-growth-rate GR
  let local-death-rate DR
  let local-decay-rate DEC
  let local-total-oxygen O
  let local-respiration-rate RR
  let local-consumption-rate CR
  let local-solution-rate SR
  let local-aeration-rate [ ka ] of this-village * ( oxygen-epi - oxygen-hyp )
  let local-feeding-rate FR
  let local-farm-algae biomass * [ farm-algae ] of this-village
  let local-dredge detritus * [ dredge ] of this-village
;; level equations
  let new-nutrient max ( list 0 ( nutrient + DT * ( local-feeding-rate - local-growth-rate + local-respiration-rate + local-decay-rate ) ) )
  let new-biomass  max ( list 0 ( biomass + DT * ( local-growth-rate - local-death-rate - local-farm-algae - local-respiration-rate ) ) )
  let new-detritus max ( list 0 ( detritus + DT * ( local-death-rate - local-decay-rate - local-dredge ) ) )
  let new-oxygen-hyp max ( list 0 ( oxygen-hyp + DT * ( local-solution-rate - local-consumption-rate + local-aeration-rate ) ) )
;; local new values are copied for next tick
  set nutrient new-nutrient
  set biomass new-biomass
  set detritus new-detritus
  set oxygen-hyp new-oxygen-hyp
;; rates are copied to patch variables just for output, never used for future calculations
  set growth-rate local-growth-rate
  set death-rate local-death-rate
  set decay-rate local-decay-rate
  set total-oxygen local-total-oxygen
  set respiration-rate local-respiration-rate
  set consumption-rate local-consumption-rate
  set solution-rate local-solution-rate
  set aeration-rate local-aeration-rate
  set feeding-rate local-feeding-rate
  set algae-harvested local-farm-algae
  set detritus-dredged local-dredge
end

to-report FR
  report ( feeding-rate-initial * food-multiplier )
end
to-report GR
  report ( k1 * biomass * nutrient )
end
to-report DEC
  report ( k3 * detritus * oxygen-hyp )
end
to-report DR
  report k2 * biomass
end
to-report RR
  report ( k4 * biomass * oxygen-hyp )
end
to-report CR
  report ( RR + DEC ) * onr
end
to-report SR
  report min ( list 20 ( k5 * ( oxygen-epi - oxygen-hyp ) ) )
end
to-report O
  report ( EHR * oxygen-epi + ( 1 - EHR ) * oxygen-hyp )
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; village behaviour / mayor behaviour
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; mayors / villages decide whether algae farming and dredging is applied and whether taxes for using fertiliser on fields are applied

to decide-measures
  let current-nutrient [ nutrient ] of nearest-water
  let current-biomass [ biomass ] of nearest-water
  let current-detritus [ detritus ] of nearest-water
  let current-oxygen [ oxygen-hyp ] of nearest-water
  ( ifelse
    current-nutrient > awareness * nutrient-initial
    [
      set TAX TAXapplied
  ;;    show ( word "TAX raised to " TAX )
    ]
    current-nutrient < nutrient-initial [ set TAX 0.0 ]
  )
  ( ifelse
    current-biomass > awareness * biomass-initial
    [
      set farmf farming-applied
;;      show ( word "farmf set to " farmf )
    ]
    current-biomass < biomass-initial [ set farm-algae 0.0 ]
  )
  ( ifelse
    current-detritus > awareness * detritus-initial
    [
      set dredge dredging-applied
;;      show ( word "dredge set to " dredge )
    ]
    current-detritus < detritus-initial [ set dredge 0.0 ]
  )
  ( ifelse
    current-oxygen < ( 1 / awareness ) * oxygen-hyp-initial
    [
      set ka aeration-applied
;;      show ( word "aeration set to " ka )
    ]
    current-oxygen > oxygen-hyp-initial [ set ka 0.0 ]
  )
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; farmer / cattle behaviour
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; farmers decide where they let their cattle graze and drop manure and whether the apply manure to their crop fields, the latter depending whether this is taxed

to decide-spreading-manure
  ( ifelse [ TAX ] of my-village < TAXthres
    [ ask patch-here
      [
        set nutrient manure-spread
;;        show ( word "spreads " nutrient " manure " )
      ]
    ]
    [
      ask patch-here
      [
        set nutrient 0
;;        show ( word "manure spreading stopped" )
      ]
    ]
  )
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; crop behaviour
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; crop is expected to consume liquid manure spread to the ground

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; persons' behaviour
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; persons smell manure and the eutrophicated lake and rivers, protest against agricultural policies and vote in mayor elections

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; industrial plants' behaviour
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; industrial plants decide whether they release poisonous fluids into the evironment

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; utilities
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to show-feature
  set min-nutrient min [ nutrient ] of rivers-and-lake
  set max-nutrient max [ nutrient ] of rivers-and-lake
  set sum-nutrient sum [ nutrient ] of rivers-and-lake
  set min-biomass min [ biomass ] of rivers-and-lake
  set max-biomass max [ biomass ] of rivers-and-lake
  set sum-biomass sum [ biomass ] of rivers-and-lake
  set min-detritus min [ detritus ] of rivers-and-lake
  set max-detritus max [ detritus ] of rivers-and-lake
  set sum-detritus sum [ detritus ] of rivers-and-lake
  set min-oxygen min [ oxygen-hyp ] of rivers-and-lake
  set max-oxygen max [ oxygen-hyp ] of rivers-and-lake
  set sum-oxygen sum [ oxygen-hyp ] of rivers-and-lake
  if feature-to-show = "categories" [ show-categories ]
  if feature-to-show = "nutrient" [ show-nutrient ]
  if feature-to-show = "biomass" [ show-biomass ]
  if feature-to-show = "detritus" [ show-detritus ]
  if feature-to-show = "oxygen" [ show-oxygen ]
end

to-report colour-code [ value minimum norm-value maximum ]
  if maximum - minimum < 1e-6 [ report grey ]
  let this-hue 0
  ifelse value < norm-value
  [ set this-hue 120 - gradient ( ( value - norm-value ) / ( minimum - norm-value ) ) * 60 ]
  [ set this-hue 120 + gradient ( ( value - norm-value ) / ( maximum - norm-value ) ) * 120 ]
  report hsb this-hue 100 100
end

to show-nutrient
  ifelse max-nutrient <= min-nutrient
  [ ask patches [ set pcolor grey ] ]
  [ ask rivers-and-lake
    [
;;      set pcolor 9.9 * ( 1 - gradient ( ( nutrient - min-nutrient) / ( max-nutrient - min-nutrient ) ) )
      set pcolor colour-code nutrient min-nutrient nutrient-initial max-nutrient
    ]
  ]
end
to show-biomass
  ifelse max-biomass <= min-biomass
  [ ask patches [ set pcolor grey ] ]
  [
    ask land [ set pcolor white ]
    ask rivers-and-lake
    [
;;      set pcolor 9.9 * ( 1 - gradient ( ( biomass - min-biomass ) / ( max-biomass - min-biomass ) ) )
      set pcolor colour-code biomass min-biomass biomass-initial max-biomass
    ]
  ]
end
to show-detritus
  ifelse max-detritus <= min-detritus
  [ ask patches [ set pcolor grey ] ]
  [
    ask land [ set pcolor white ]
    ask rivers-and-lake
    [
;;      set pcolor 9.9 * ( 1 - gradient ( ( detritus - min-detritus ) / ( max-detritus - min-detritus ) ) )
      set pcolor colour-code detritus min-detritus detritus-initial max-detritus
    ]
  ]
end
to show-oxygen
  ifelse max-oxygen <= min-oxygen
  [ ask patches [ set pcolor grey ] ]
  [
    ask land [ set pcolor white ]
    ask rivers-and-lake
    [
;;      set pcolor 9.9 * ( 1 - gradient ( ( oxygen-hyp - min-oxygen ) / ( max-oxygen - min-oxygen ) ) )
      set pcolor colour-code oxygen-hyp min-oxygen oxygen-hyp-initial max-oxygen
    ]
  ]
end

to-report gradient [ x ]
  let grad 0
  ( ifelse
    grad-visual = "sqr" [ set grad sqr x ]
    grad-visual = "sqrt" [ set grad sqrt x ]
    grad-visual = "lin" [ set grad x ]
    grad-visual = "p10" [ set grad x ^ 10 ]
    grad-visual = "cub" [ set grad 0.5 + ( x - 0.5 ) ^ 3  * ( 2 ^ 2 ) ]
    grad-visual = "p05" [ set grad 0.5 + ( x - 0.5 ) ^ 5  * ( 2 ^ 4 ) ]
    grad-visual = "p07" [ set grad 0.5 + ( x - 0.5 ) ^ 7  * ( 2 ^ 6 ) ]
    grad-visual = "p09" [ set grad 0.5 + ( x - 0.5 ) ^ 9  * ( 2 ^ 8 ) ]
  )
  report grad
end

to-report sqr [ x ]
  report x * x
end

to show-categories
  ask patches
  [
    if is-residential? [ set pcolor yellow ]
    if is-industry?    [ set pcolor red ]
    if is-agro?        [ set pcolor green ]
    if is-river? or is-lake? [ set pcolor blue ]
    if is-wood?        [ set pcolor green - 3 ]
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
560
13
1275
729
-1
-1
7.0
1
10
1
1
1
0
0
0
1
-50
50
-50
50
0
0
1
ticks
30.0

BUTTON
5
10
73
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
79
10
147
43
NIL
go\n
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
129
103
232
148
max nutrient
max-nutrient
4
1
11

MONITOR
26
103
128
148
min nutrient
min-nutrient
4
1
11

MONITOR
234
103
405
148
rng nutrient
max-nutrient - min-nutrient
17
1
11

MONITOR
26
149
128
194
min biomass
min-biomass
4
1
11

MONITOR
234
149
405
194
rng biomass
max-biomass - min-biomass
17
1
11

MONITOR
129
149
232
194
max biomass
max-biomass
4
1
11

MONITOR
26
195
128
240
min detritus
min-detritus
4
1
11

MONITOR
234
195
405
240
rng detritus
max-detritus - min-detritus
17
1
11

MONITOR
129
195
232
240
max detritus
max-detritus
4
1
11

MONITOR
26
241
128
286
min oxygen
min-oxygen
4
1
11

MONITOR
234
241
404
286
rng oxygen
max-oxygen - min-oxygen
17
1
11

MONITOR
129
241
232
286
max oxygen
max-oxygen
4
1
11

CHOOSER
30
406
169
451
feature-to-show
feature-to-show
"categories" "nutrient" "biomass" "oxygen" "detritus"
1

BUTTON
157
10
220
43
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
12
58
184
91
DT
DT
0
0.1
0.05
0.005
1
NIL
HORIZONTAL

PLOT
1290
13
1831
229
State of patches
years
ND(0,50), O(0,10), B(0,2)
0.0
1.0
0.0
1.0
true
true
"" ""
PENS
"nutrient (*50)" 1.0 0 -955883 true "" "plotxy time 0.02 * mean [ nutrient ] of rivers-and-lake"
"biomass (* 2)" 1.0 0 -13840069 true "" "plotxy time 0.5 * mean [ biomass ] of rivers-and-lake"
"oxygen-hyp (*10)" 1.0 0 -11221820 true "" "plotxy time 0.1 * mean [ oxygen-hyp ] of rivers-and-lake"
"detritus (*50)" 1.0 0 -7500403 true "" "plotxy time 0.02 * mean [ detritus ] of rivers-and-lake"

MONITOR
433
103
529
148
growth rate
mean [ growth-rate ] of rivers-and-lake
3
1
11

MONITOR
433
149
529
194
death rate
mean [ death-rate ] of rivers-and-lake
3
1
11

MONITOR
433
195
529
240
decay rate
mean [ decay-rate ] of rivers-and-lake
3
1
11

MONITOR
433
241
529
286
resp rate
mean [ respiration-rate ] of rivers-and-lake
3
1
11

MONITOR
433
287
529
332
consum rate
mean [ consumption-rate ] of rivers-and-lake
3
1
11

MONITOR
433
333
529
378
solu rate
mean [ solution-rate ] of rivers-and-lake
3
1
11

MONITOR
433
379
529
424
aer rate
mean [ aeration-rate ] of rivers-and-lake
3
1
11

MONITOR
433
425
529
470
feed rate
mean [ feeding-rate ] of rivers-and-lake
3
1
11

BUTTON
184
407
310
440
show feature
show-feature
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
195
59
324
92
dissipate?
dissipate?
0
1
-1000

SWITCH
24
521
205
554
food-mult-switch?
food-mult-switch?
1
1
-1000

CHOOSER
24
556
162
601
policy-impl-time
policy-impl-time
0 100 200
2

CHOOSER
24
602
235
647
anderson-run
anderson-run
"micro version" "basic" "natural eutrophication" "recovery" "growth" "algicide" "aeration" "dredging" "farming"
0

MONITOR
245
471
353
516
NIL
food-multiplier
3
1
11

MONITOR
245
517
302
562
NIL
k2b
17
1
11

MONITOR
245
563
302
608
NIL
kaer
17
1
11

MONITOR
245
609
302
654
NIL
drdgf
3
1
11

MONITOR
245
655
302
700
NIL
farmf
3
1
11

PLOT
1290
233
1831
449
State change rates
NIL
NIL
0.0
1.0
0.0
10.0
true
true
"" ""
PENS
"growth-rate" 1.0 0 -13840069 true "" "plotxy time mean [ growth-rate ] of rivers-and-lake"
"death-rate" 1.0 0 -16777216 true "" "plotxy time mean [ death-rate ] of rivers-and-lake"
"decay-rate" 1.0 0 -7500403 true "" "plotxy time mean [ decay-rate ] of rivers-and-lake"
"respiration-rate" 1.0 0 -13791810 true "" "plotxy time mean [ respiration-rate ] of rivers-and-lake"
"consumptiion-rate" 1.0 0 -2674135 true "" "plotxy time mean [ consumption-rate ] of rivers-and-lake"
"solution-rate" 1.0 0 -955883 true "" "plotxy time mean [ solution-rate ] of rivers-and-lake"
"harvesting-rate" 1.0 0 -10899396 true "" "plotxy time mean [ algae-harvested ] of rivers-and-lake"
"pen-7" 1.0 0 -6459832 true "" "plotxy time mean [ detritus-dredged ] of rivers-and-lake"

MONITOR
433
471
529
516
algae harv
mean [ algae-harvested ] of rivers-and-lake
4
1
11

MONITOR
433
517
529
562
detr dredged
mean [ detritus-dredged ] of rivers-and-lake
6
1
11

SLIDER
25
289
197
322
manure-spread
manure-spread
0
20
10.0
1
1
NIL
HORIZONTAL

SLIDER
25
324
197
357
TAXapplied
TAXapplied
0
50
0.0
1
1
NIL
HORIZONTAL

SLIDER
25
359
197
392
farming-applied
farming-applied
0
1
0.3
0.1
1
NIL
HORIZONTAL

SLIDER
205
289
377
322
aeration-applied
aeration-applied
0
1
0.7
0.1
1
NIL
HORIZONTAL

SLIDER
205
324
377
357
dredging-applied
dredging-applied
0
1
0.6
0.1
1
NIL
HORIZONTAL

SLIDER
205
359
377
392
awareness
awareness
1
1.3
1.0
0.05
1
NIL
HORIZONTAL

PLOT
1290
460
1490
610
nutrient in water
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"set-plot-pen-mode 1\nset-histogram-num-bars 20" "set-plot-pen-mode 1\nset-histogram-num-bars 20\nif max-nutrient > min-nutrient [ set-plot-x-range floor min-nutrient ceiling max-nutrient ]"
PENS
"default" 1.0 0 -16777216 true "" "histogram [ nutrient ] of rivers-and-lake"

PLOT
1500
460
1700
610
biomass in water
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"set-plot-pen-mode 1\nset-histogram-num-bars 20" "set-plot-pen-mode 1\nset-histogram-num-bars 20\nif precision ( max-biomass * 1.05 ) 3 > precision min-biomass 3 [ set-plot-x-range precision min-biomass 3 precision ( max-biomass * 1.05 ) 3 ]"
PENS
"default" 1.0 0 -16777216 true "" "histogram [ biomass ] of rivers-and-lake"

PLOT
1290
620
1490
770
detritus in water
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"set-plot-pen-mode 1\nset-histogram-num-bars 20" "set-plot-pen-mode 1\nset-histogram-num-bars 20\nif max-detritus > min-detritus [ set-plot-x-range floor min-detritus ceiling max-detritus ]"
PENS
"default" 1.0 0 -16777216 true "" "histogram [ detritus ] of rivers-and-lake"

PLOT
1500
620
1700
770
oxygen in water
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"set-plot-pen-mode 1\nset-histogram-num-bars 20" "set-plot-pen-mode 1\nset-histogram-num-bars 20\nif max-oxygen > min-oxygen [ set-plot-x-range floor min-oxygen ceiling max-oxygen ]"
PENS
"default" 1.0 0 -16777216 true "" "histogram [ oxygen-hyp ] of rivers-and-lake"

CHOOSER
28
453
166
498
grad-visual
grad-visual
"sqr" "sqrt" "lin" "p10" "cub" "p05" "p07" "p09"
2

SWITCH
340
61
457
94
logging?
logging?
1
1
-1000

MONITOR
328
570
431
615
nutrient
( list precision nutrient-overall-max 3 precision nutrient-overall-min 3 )
17
1
11

MONITOR
328
616
431
661
biomass
( list precision biomass-overall-max 3 precision biomass-overall-min 3 )
17
1
11

MONITOR
328
662
431
707
detritus
( list precision detritus-overall-max 3 precision detritus-overall-min 3 )
17
1
11

MONITOR
328
708
431
753
oxygen
( list precision oxygen-overall-max 3 precision oxygen-overall-min 3 )
17
1
11

SWITCH
24
648
211
681
equal-dissipation?
equal-dissipation?
0
1
-1000

SWITCH
228
10
397
43
constant-seed?
constant-seed?
0
1
-1000

MONITOR
412
12
550
57
NIL
setup-randomseed
17
1
11

MONITOR
30
746
147
791
year and month
( word floor time \"-\" month )
17
1
11

@#$#@#$#@
## WHAT IS IT?

The purpose of this study is another agent-based replication of a System Dynamics model (Ander- son,1973) where he analysed the dynamics of nutrient, biomass, oxygen and detritus in a model lake under conditions of artiﬁcial fertilising and policies to deal with the consequences of artiﬁcial fer- tilising.. A ﬁrst replication (Möhring & Troitzsch,2001) added those agents to the original model that were necessary to move the role of the experimenter into the model, whereas this replication replaces the original lake with a collection of small elements between which biomass, nutrients and oxygen are exchanged, adds rivers upstream and downstream as well as adjacent land divided into villages and populated with farms and industrial plants run by individual persons.

## HOW IT WORKS

All details are described in an ODD+D description attached to the model at ComSES.

## HOW TO USE IT

All details are described in an ODD+D description attached to the model at ComSES.

## THINGS TO NOTICE

All details are described in an ODD+D description attached to the model at ComSES.

## THINGS TO TRY

All details are described in an ODD+D description attached to the model at ComSES.

## EXTENDING THE MODEL

All details are described in an ODD+D description attached to the model at ComSES.

## NETLOGO FEATURES

No special features are used.

## RELATED MODELS

None so far.

## CREDITS AND REFERENCES

Anderson, J.M. (1973). The eutrophication of lakes. D. Meadows & D. Mead- ows (Eds.), Toward global equilibrium (pp. 171–140). Cambridge MA: Wright Allen.

Möhring, M., & Troitzsch, K.G. (2001). Lake Anderson revisited. Jour- nal of Artiﬁcial Societies and Social Simulation, 4/3/1 . Retrieved from http://jasss.soc.surrey.ac.uk/4/3/1.html
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

building institution
false
0
Rectangle -7500403 true true 0 60 300 270
Rectangle -16777216 true false 130 196 168 256
Rectangle -16777216 false false 0 255 300 270
Polygon -7500403 true true 0 60 150 15 300 60
Polygon -16777216 false false 0 60 150 15 300 60
Circle -1 true false 135 26 30
Circle -16777216 false false 135 25 30
Rectangle -16777216 false false 0 60 300 75
Rectangle -16777216 false false 218 75 255 90
Rectangle -16777216 false false 218 240 255 255
Rectangle -16777216 false false 224 90 249 240
Rectangle -16777216 false false 45 75 82 90
Rectangle -16777216 false false 45 240 82 255
Rectangle -16777216 false false 51 90 76 240
Rectangle -16777216 false false 90 240 127 255
Rectangle -16777216 false false 90 75 127 90
Rectangle -16777216 false false 96 90 121 240
Rectangle -16777216 false false 179 90 204 240
Rectangle -16777216 false false 173 75 210 90
Rectangle -16777216 false false 173 240 210 255
Rectangle -16777216 false false 269 90 294 240
Rectangle -16777216 false false 263 75 300 90
Rectangle -16777216 false false 263 240 300 255
Rectangle -16777216 false false 0 240 37 255
Rectangle -16777216 false false 6 90 31 240
Rectangle -16777216 false false 0 75 37 90
Line -16777216 false 112 260 184 260
Line -16777216 false 105 265 196 265

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

factory
false
0
Rectangle -7500403 true true 76 194 285 270
Rectangle -7500403 true true 36 95 59 231
Rectangle -16777216 true false 90 210 270 240
Line -7500403 true 90 195 90 255
Line -7500403 true 120 195 120 255
Line -7500403 true 150 195 150 240
Line -7500403 true 180 195 180 255
Line -7500403 true 210 210 210 240
Line -7500403 true 240 210 240 240
Line -7500403 true 90 225 270 225
Circle -1 true false 37 73 32
Circle -1 true false 55 38 54
Circle -1 true false 96 21 42
Circle -1 true false 105 40 32
Circle -1 true false 129 19 42
Rectangle -7500403 true true 14 228 78 270

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

house ranch
false
0
Rectangle -7500403 true true 270 120 285 255
Rectangle -7500403 true true 15 180 270 255
Polygon -7500403 true true 0 180 300 180 240 135 60 135 0 180
Rectangle -16777216 true false 120 195 180 255
Line -7500403 true 150 195 150 255
Rectangle -16777216 true false 45 195 105 240
Rectangle -16777216 true false 195 195 255 240
Line -7500403 true 75 195 75 240
Line -7500403 true 225 195 225 240
Line -16777216 false 270 180 270 255
Line -16777216 false 0 180 300 180

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

person farmer
false
0
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -1 true false 60 195 90 210 114 154 120 195 180 195 187 157 210 210 240 195 195 90 165 90 150 105 150 150 135 90 105 90
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -13345367 true false 120 90 120 180 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 180 90 172 89 165 135 135 135 127 90
Polygon -6459832 true false 116 4 113 21 71 33 71 40 109 48 117 34 144 27 180 26 188 36 224 23 222 14 178 16 167 0
Line -16777216 false 225 90 270 90
Line -16777216 false 225 15 225 90
Line -16777216 false 270 15 270 90
Line -16777216 false 247 15 247 90
Rectangle -6459832 true false 240 90 255 300

person graduate
false
0
Circle -16777216 false false 39 183 20
Polygon -1 true false 50 203 85 213 118 227 119 207 89 204 52 185
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -8630108 true false 90 19 150 37 210 19 195 4 105 4
Polygon -8630108 true false 120 90 105 90 60 195 90 210 120 165 90 285 105 300 195 300 210 285 180 165 210 210 240 195 195 90
Polygon -1184463 true false 135 90 120 90 150 135 180 90 165 90 150 105
Line -2674135 false 195 90 150 135
Line -2674135 false 105 90 150 135
Polygon -1 true false 135 90 150 105 165 90
Circle -1 true false 104 205 20
Circle -1 true false 41 184 20
Circle -16777216 false false 106 206 18
Line -2674135 false 208 22 208 57

person service
false
0
Polygon -7500403 true true 180 195 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285
Polygon -1 true false 120 90 105 90 60 195 90 210 120 150 120 195 180 195 180 150 210 210 240 195 195 90 180 90 165 105 150 165 135 105 120 90
Polygon -1 true false 123 90 149 141 177 90
Rectangle -7500403 true true 123 76 176 92
Circle -7500403 true true 110 5 80
Line -13345367 false 121 90 194 90
Line -16777216 false 148 143 150 196
Rectangle -16777216 true false 116 186 182 198
Circle -1 true false 152 143 9
Circle -1 true false 152 166 9
Rectangle -16777216 true false 179 164 183 186
Polygon -2674135 true false 180 90 195 90 183 160 180 195 150 195 150 135 180 90
Polygon -2674135 true false 120 90 105 90 114 161 120 195 150 195 150 135 120 90
Polygon -2674135 true false 155 91 128 77 128 101
Rectangle -16777216 true false 118 129 141 140
Polygon -2674135 true false 145 91 172 77 172 101

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>nutrient-overall-max</metric>
    <metric>nutrient-overall-min</metric>
    <metric>biomass-overall-max</metric>
    <metric>biomass-overall-min</metric>
    <metric>oxygen-overall-max</metric>
    <metric>oxygen-overall-min</metric>
    <metric>detritus-overall-max</metric>
    <metric>detritus-overall-min</metric>
    <enumeratedValueSet variable="feature-to-show">
      <value value="&quot;categories&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy-impl-time">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="logging?">
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="farming-applied" first="0.1" step="0.2" last="0.9"/>
    <steppedValueSet variable="dredging-applied" first="0.1" step="0.2" last="0.9"/>
    <steppedValueSet variable="manure-spread" first="0" step="2" last="10"/>
    <enumeratedValueSet variable="anderson-run">
      <value value="&quot;micro version&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DT">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grad-visual">
      <value value="&quot;cub&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="aeration-applied" first="0.1" step="0.2" last="0.9"/>
    <enumeratedValueSet variable="dissipate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-mult-switch?">
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="TAXapplied" first="10" step="10" last="50"/>
  </experiment>
  <experiment name="experiment2" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>farming-applied</metric>
    <metric>dredging-applied</metric>
    <metric>aeration-applied</metric>
    <metric>TAXapplied</metric>
    <metric>manure-spread</metric>
    <metric>nutrient-overall-max</metric>
    <metric>nutrient-overall-min</metric>
    <metric>biomass-overall-max</metric>
    <metric>biomass-overall-min</metric>
    <metric>oxygen-overall-max</metric>
    <metric>oxygen-overall-min</metric>
    <metric>detritus-overall-max</metric>
    <metric>detritus-overall-min</metric>
    <enumeratedValueSet variable="feature-to-show">
      <value value="&quot;categories&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy-impl-time">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="logging?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anderson-run">
      <value value="&quot;micro version&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DT">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grad-visual">
      <value value="&quot;cub&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissipate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-mult-switch?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="equal-dissipation?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment3" repetitions="200" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>farming-applied</metric>
    <metric>dredging-applied</metric>
    <metric>aeration-applied</metric>
    <metric>TAXapplied</metric>
    <metric>manure-spread</metric>
    <metric>awareness</metric>
    <metric>nutrient-overall-max</metric>
    <metric>nutrient-overall-min</metric>
    <metric>biomass-overall-max</metric>
    <metric>biomass-overall-min</metric>
    <metric>oxygen-overall-max</metric>
    <metric>oxygen-overall-min</metric>
    <metric>detritus-overall-max</metric>
    <metric>detritus-overall-min</metric>
    <enumeratedValueSet variable="feature-to-show">
      <value value="&quot;categories&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy-impl-time">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="logging?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anderson-run">
      <value value="&quot;micro version&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DT">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grad-visual">
      <value value="&quot;cub&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dissipate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-mult-switch?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="equal-dissipation?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
